@@ -13,11 +13,9 @@ from gnomad.sample_qc.filtering import (
     compute_qc_metrics_residuals,
     compute_stratified_metrics_filter,
 )
-from gnomad.sample_qc.pipeline import get_qc_mt
 from gnomad.sample_qc.filtering import compute_stratified_sample_qc
 from gnomad.sample_qc.pipeline import annotate_sex
 from gnomad.utils.file_utils import file_exists
-from gnomad.utils.annotations import get_adj_expr
 from gnomad.utils.annotations import bi_allelic_expr
 from gnomad.utils.filtering import filter_to_autosomes
 from gnomad.utils.sparse_mt import filter_ref_blocks
@@ -101,8 +99,7 @@ def compute_hail_sample_qc(
         }
     )
     sample_qc_ht = sample_qc_ht.repartition(100)
-    sample_qc_ht.write(out_ht_path, overwrite=True)
-    return sample_qc_ht
+    return sample_qc_ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def snps_not_in_gnomad(
@@ -138,8 +135,7 @@ def snps_not_in_gnomad(
     ht = ht.key_by('locus', 'alleles').anti_join(gnomad)
     # Count non-gnomad variants for each sample
     stats_ht = ht.group_by(ht.s).aggregate(nongnomad_snps=hl.agg.count())
-    stats_ht.write(out_ht_path, overwrite=True)
-    return stats_ht
+    return stats_ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def infer_sex(
@@ -156,7 +152,7 @@ def infer_sex(
     :param out_ht_path: location to write the result to
     :param overwrite: overwrite checkpoints if they exist
     :param target_regions: if exomes, it should correspond to the regions in the panel
-    :return: a Hail Table with the following row fields:
+    :return: a Table with the following row fields:
         'is_female': bool
         'f_stat': float64
         'n_called': int64
@@ -183,139 +179,25 @@ def infer_sex(
         gt_expr='LGT',
     )
 
-    ht.write(out_ht_path, overwrite=True)
-    return ht
-
-
-def make_mt_for_pca(
-    mt: hl.MatrixTable,
-    info_ht: hl.Table,
-    work_bucket: str,
-    overwrite: bool,
-) -> hl.MatrixTable:
-    """
-    Create a new MatrixTable suitable for PCA analysis of relatedness
-    and ancestry.
-    * Strips unnesessary entry-level fields.
-    * Keeps only bi-allelic SNPs.
-    * Calls gnomad_methods's get_qc_mt() to filter rows further down based on:
-      - the presence in problematic regions
-      - callrate thresholds
-      - MAF thresholds
-      - inbreeding coefficient
-      - allelic frequency thresholds
-      - genotypes ADJ critetria (GQ>=20, DP>=10, AB>0.2 for hets)
-
-    :param mt: input matrix table
-    :param info_ht: per-site table generated by generate_info_ht.py, with the
-        following columns: QD, FS, MQ
-    :param work_bucket: path to write checkpoints
-    :param overwrite: overwrite checkpoints if they exist
-    :return: matrix table with variants selected for PCA analysis
-    """
-    logger.info('Making MatrixTable for PCA analysis')
-    mt = mt.select_entries(
-        'END', GT=mt.LGT, adj=get_adj_expr(mt.LGT, mt.GQ, mt.DP, mt.LAD)
-    )
-    mt = mt.filter_rows(
-        (hl.len(mt.alleles) == 2) & hl.is_snp(mt.alleles[0], mt.alleles[1])
-    )
-    mt = mt.naive_coalesce(5000)
-
-    info_ht = info_ht.annotate(
-        info=info_ht.info.select(
-            # No need for AS_annotations since it's bi-allelic sites only
-            **{x: info_ht.info[x] for x in info_ht.info if not x.startswith('AS_')}
-        )
-    )
-    mt = mt.annotate_rows(info=info_ht[mt.row_key].info)
-
-    return get_qc_mt(
-        mt,
-        adj_only=False,
-        min_af=0.0,
-        min_inbreeding_coeff_threshold=-0.025,
-        min_hardy_weinberg_threshold=None,
-        ld_r2=None,
-        filter_lcr=False,
-        filter_decoy=False,
-        filter_segdup=False,
-    ).checkpoint(
-        join(work_bucket, 'for_pca.mt'),
-        overwrite=overwrite,
-        _read_if_exists=not overwrite,
-    )
-
-
-def compute_relatedness(
-    for_pca_mt: hl.MatrixTable,
-    tmp_bucket: str,
-    out_ht_path: Optional[str] = None,
-    overwrite: bool = False,
-) -> hl.Table:
-    """
-    :param for_pca_mt: variants selected for PCA analysis
-    :param tmp_bucket: path to write checkpoints
-    :param out_ht_path: path to write relatedness data
-    :param overwrite: overwrite checkpoints if they exist
-    :return: table with the following structure:
-    Row fields:
-        'i': str
-        'j': str
-        'kin': float64
-        'ibd0': float64
-        'ibd1': float64
-        'ibd2': float64
-    ----------------------------------------
-    Key: ['i', 'j']
-    """
-    logger.info('Running relatedness check')
-    out_ht_path = out_ht_path or join(tmp_bucket, 'relatedness.ht')
-    if utils.can_reuse(out_ht_path, overwrite):
-        return hl.read_table(out_ht_path)
-
-    sample_num = for_pca_mt.cols().count()
-
-    _, scores, _ = hl.hwe_normalized_pca(
-        for_pca_mt.GT, k=max(1, min(sample_num // 3, 10)), compute_loadings=False
-    )
-    scores = scores.checkpoint(
-        join(tmp_bucket, 'relatedness_pca_scores.ht'),
-        overwrite=overwrite,
-        _read_if_exists=not overwrite,
-    )
-    relatedness_ht = hl.pc_relate(
-        for_pca_mt.GT,
-        min_individual_maf=0.01,
-        scores_expr=scores[for_pca_mt.col_key].scores,
-        block_size=4096,
-        min_kinship=0.05,
-        statistics='all',
-    )
-
-    # Converting keys for type struct{str} to str to align
-    # with the rank_ht `s` key:
-    relatedness_ht = relatedness_ht.key_by(i=relatedness_ht.i.s, j=relatedness_ht.j.s)
-    relatedness_ht.write(out_ht_path, overwrite=True)
-    return relatedness_ht
+    return ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def run_pca_ancestry_analysis(
-    for_pca_mt: hl.MatrixTable,
+    mt_biall: hl.MatrixTable,
     sample_to_drop_ht: hl.Table,
     tmp_bucket: str,
     n_pcs: int,
     overwrite: bool = False,
 ) -> hl.Table:
     """
-    :param for_pca_mt: variants usable for PCA analysis
+    :param mt_biall: variants usable for PCA analysis
         of the same type, identifying the pair of samples for each row
     :param tmp_bucket: bucket path to write checkpoints
     :param sample_to_drop_ht: table with samples to drop based on
         previous relatedness analysis. With a `rank` row field
     :param n_pcs: maximum number of principal components
     :param overwrite: overwrite checkpoints if they exist
-    :return: a Hail table `scores_ht` with a row field:
+    :return: a Table with a row field:
         'scores': array<float64>
     """
     logger.info('Running PCA ancestry analysis')
@@ -325,10 +207,9 @@ def run_pca_ancestry_analysis(
 
     # Adjusting the number of principal components not to exceed the
     # number of samples
-    n_pcs = min(n_pcs, for_pca_mt.cols().count() - sample_to_drop_ht.count())
-    _, scores_ht, _ = run_pca_with_relateds(for_pca_mt, sample_to_drop_ht, n_pcs=n_pcs)
-    scores_ht.write(scores_ht_path, overwrite=True)
-    return scores_ht
+    n_pcs = min(n_pcs, mt_biall.cols().count() - sample_to_drop_ht.count())
+    _, scores_ht, _ = run_pca_with_relateds(mt_biall, sample_to_drop_ht, n_pcs=n_pcs)
+    return scores_ht.checkpoint(scores_ht_path, overwrite=True)
 
 
 def assign_pops(
@@ -357,7 +238,7 @@ def assign_pops(
     :param n_pcs: Number of PCs to use in the RF
     :param out_ht_path: Path to write the resulting HT table
     :param overwrite: overwrite checkpoints if they exist
-    :return: a table with the following row fields, including `prob_<POP>`
+    :return: a Table with the following row fields, including `prob_<POP>`
         probabily fields for each population label:
         'training_pop': str
         'pca_scores': array<float64>
@@ -427,8 +308,7 @@ def assign_pops(
         with hl.hadoop_open(pop_rf_file, 'wb') as out:
             pickle.dump(pops_rf_model, out)
 
-    pop_ht.write(out_ht_path, overwrite=True)
-    return pop_ht
+    return pop_ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def compute_stratified_qc(
@@ -551,8 +431,7 @@ def flag_related_samples(
         kin_threshold=kin_threshold,
         filtered_samples=filtered_samples,
     )
-    samples_to_drop_ht.write(out_ht_path, overwrite=True)
-    return samples_to_drop_ht
+    return samples_to_drop_ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def _compute_sample_rankings(
@@ -700,8 +579,7 @@ def apply_regressed_filters(
         **stratified_metrics_ht.index_globals()
     )
 
-    residuals_ht.write(out_ht_path, overwrite=True)
-    return residuals_ht
+    return residuals_ht.checkpoint(out_ht_path, overwrite=True)
 
 
 def compute_hard_filters(
@@ -818,5 +696,4 @@ def compute_hard_filters(
     )
     ht = ht.annotate_globals(hard_filter_cutoffs=hl.struct(**cutoffs_d))
     ht = ht.filter(hl.len(ht.hard_filters) > 0)
-    ht.write(out_ht_path, overwrite=True)
-    return ht
+    return ht.checkpoint(out_ht_path, overwrite=True)
