@@ -11,9 +11,11 @@ from hailtop.batch.job import Job
 from analysis_runner import dataproc
 
 from joint_calling import utils
+from joint_calling.utils import can_reuse
 
-logger = logging.getLogger('joint-calling')
-logger.setLevel('INFO')
+logger = logging.getLogger(__file__)
+logging.basicConfig(format='%(levelname)s (%(name)s %(lineno)s): %(message)s')
+logger.setLevel(logging.INFO)
 
 
 SNP_RECALIBRATION_TRANCHE_VALUES = [
@@ -183,7 +185,7 @@ def make_vqsr_jobs(
     huge_disk = 100 if is_small_callset else (500 if not is_huge_callset else 2000)
 
     combined_vcf_path = join(work_bucket, 'input.vcf.gz')
-    if overwrite or not utils.file_exists(combined_vcf_path):
+    if not can_reuse(combined_vcf_path, overwrite):
         mt_to_vcf_job = dataproc.hail_dataproc_job(
             b,
             f'{scripts_dir}/mt_to_vcf.py --overwrite '
@@ -312,7 +314,7 @@ def make_vqsr_jobs(
                 indels_tranches=indels_tranches,
                 snps_recalibration=snps_recalibrations[idx],
                 snps_tranches=snps_gathered_tranches,
-                disk_size=medium_disk,
+                disk_size=huge_disk,
                 indel_filter_level=vqsr_params_d['indel_filter_level'],
                 snp_filter_level=vqsr_params_d['snp_filter_level'],
             ).recalibrated_vcf
@@ -348,7 +350,7 @@ def make_vqsr_jobs(
             indels_tranches=indels_tranches,
             snps_recalibration=snps_recalibration,
             snps_tranches=snps_tranches,
-            disk_size=medium_disk,
+            disk_size=huge_disk,
             indel_filter_level=vqsr_params_d['indel_filter_level'],
             snp_filter_level=vqsr_params_d['snp_filter_level'],
         )
@@ -992,10 +994,16 @@ def add_apply_recalibration_step(
 
     j.command(
         f"""set -euo pipefail
+        
+    df -h; pwd; du -sh $(dirname {j.recalibrated_vcf['vcf.gz']})
+    
+    TMP_DIR=$(dirname {j.recalibrated_vcf['vcf.gz']})/tmp
+    mkdir $TMP_DIR
 
     gatk --java-options -Xms5g \\
       ApplyVQSR \\
-      -O tmp.indel.recalibrated.vcf \\
+      --tmp-dir $TMP_DIR \\
+      -O tmp.indel.recalibrated.vcf.gz \\
       -V {input_vcf['vcf.gz']} \\
       --recal-file {indels_recalibration} \\
       --tranches-file {indels_tranches} \\
@@ -1005,17 +1013,29 @@ def add_apply_recalibration_step(
       {f'-L {interval} ' if interval else ''} \\
       --use-allele-specific-annotations
 
+    df -h; pwd; du -sh $(dirname {j.recalibrated_vcf['vcf.gz']})
+
+    rm {input_vcf['vcf.gz']} {indels_recalibration} {indels_tranches}
+    rm -rf $TMP_DIR
+    mkdir $TMP_DIR
+
+    df -h; pwd; du -sh $(dirname {j.recalibrated_vcf['vcf.gz']})
+
     gatk --java-options -Xms5g \\
       ApplyVQSR \\
+      --tmp-dir $TMP_DIR \\
       -O {j.recalibrated_vcf['vcf.gz']} \\
-      -V tmp.indel.recalibrated.vcf \\
+      -V tmp.indel.recalibrated.vcf.gz \\
       --recal-file {snps_recalibration} \\
       --tranches-file {snps_tranches} \\
       --truth-sensitivity-filter-level {snp_filter_level} \\
       --create-output-variant-index true \\
       -mode SNP \\
       {f'-L {interval} ' if interval else ''} \\
-      --use-allele-specific-annotations"""
+      --use-allele-specific-annotations
+
+    df -h; pwd; du -sh $(dirname {j.recalibrated_vcf['vcf.gz']})
+    """
     )
 
     if output_vcf_path:
